// -*- C++ -*-
// $RCSfile: csrmatrix.h,v $
// $Revision: 1.9 $
// $Author: reida $
// $Date: 2006-02-27 20:59:40 $

/* This software was produced by NIST, an agency of the U.S. government,
 * and by statute is not subject to copyright in the United States.
 * Recipients of this software assume all responsibilities associated
 * with its operation, modification and maintenance. However, to
 * facilitate maintenance we ask that before distributing modified
 * versions of this software, you first contact the authors at
 * oof_manager@ctcms.nist.gov. 
 */

#include <oofconfig.h>

// Compressed sparse row matrix (of type SPARSE_MATRIX_D, defined in
// matvec.h) wrapped up with an AutoMatrix to make it a reference
// counted class, and with a Python output operator attached.

// Because CSRmatrix is derived from AutoMatrix<SPARSE_MATRIX_D>, and
// because an AutoMatrix can be implicitly converted to its underlying
// TYPE, a CSRmatrix can be used whereever a SPARSE_MATRIX_D is
// expected.

#ifndef CSRMATRIX_H
#define CSRMATRIX_H

#include "common/tostring.h"
#include "engine/automatrix.h"
#include "engine/matvec.h"
#include <iostream>
#include <string>

class CSRmatrix : public AutoMatrix<SPARSE_MATRIX_D> {
public:
  template <class MTX, class VEC>
  CSRmatrix(const MTX &m, const VEC &rowmap, const VEC &colmap)
    : AutoMatrix<SPARSE_MATRIX_D>(new SPARSE_MATRIX_D(m, rowmap, colmap), true)
  {}

  CSRmatrix(const SPARSE_MATRIX_D &m)
    : AutoMatrix<SPARSE_MATRIX_D>(new SPARSE_MATRIX_D(m), true)
  {}

  CSRmatrix(SPARSE_MATRIX_D &m) : AutoMatrix<SPARSE_MATRIX_D>(&m, false) {}

  CSRmatrix(SPARSE_MATRIX_D *m, bool owner)
    : AutoMatrix<SPARSE_MATRIX_D>(m, owner)
  {}

  std::string repr() const {	// for Python output
    return to_string(*this);
  }
  friend const CSRmatrix operator+(const CSRmatrix&, const CSRmatrix&);
};

const CSRmatrix operator+(const CSRmatrix &a, const CSRmatrix &b);

#endif // CSRmatrix
