// -*- C++ -*-
// $RCSfile: orientation.h,v $
// $Revision: 1.20 $
// $Author: langer $
// $Date: 2007-05-24 20:13:34 $

/* This software was produced by NIST, an agency of the U.S. government,
 * and by statute is not subject to copyright in the United States.
 * Recipients of this software assume all responsibilities associated
 * with its operation, modification and maintenance. However, to
 * facilitate maintenance we ask that before distributing modified
 * versions of this software, you first contact the authors at
 * oof_manager@ctcms.nist.gov. 
 */

#include <oofconfig.h>

#ifndef ORIENTATION_H
#define ORIENTATION_H

#include "engine/property.h"
#include "engine/corientation.h"
#include "engine/matvec.h"
#include <string>

class CMicrostructure;
class Element;
class ICoord;
class FEMesh;
class MasterPosition;

class OrientationPropBase : public Property {
public:
  OrientationPropBase(PyObject *registry, const std::string &name)
    : Property(name, registry)
  {}
  virtual const COrientation *orientation() const = 0;
  virtual const COrientation *orientation(const FEMesh*, const Element*,
					  const MasterPosition&) const = 0;
  virtual const COrientation *orientation(const CMicrostructure*, const ICoord&)
    const = 0;
  virtual bool constant_in_space() const = 0;
  virtual bool is_symmetric(const CSubProblem*) const { return true; }
};

class OrientationProp : public OrientationPropBase {
private:
  const COrientation *orient;
public:
  OrientationProp(PyObject *registry, const std::string &name, 
		  const COrientation *orient);
  ~OrientationProp();
  virtual const COrientation *orientation() const { return orient; }
  virtual const COrientation *orientation(const FEMesh*, const Element*,
				    const MasterPosition&) const;
  virtual const COrientation *orientation(const CMicrostructure*, const ICoord&)
    const;
  virtual bool constant_in_space() const { return true; }
};

#endif
